# Signal Creator

This is the signal creator Package developed by Camilo Rey, to 
create periodic signals that are _flavored_ by stochastic noise and
_perturbations_ following a deceptively simple mathematical model. 

There are two main components in this package (i.e. sub-packages). The 
*functions* package where the basic signal functions are located 
(i.e. periodic functions and gaussian noise) to create signals that
can be sampled (automatically to 100 points), and the *perturbation* 
subpackage that allows us to extend a base class _Perturbation_ to 
mess basic harmonic signals. 



This readme was created using the 
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/).